Data

Struct Data 

pub struct Data<'a> { /* private fields */ }
Span data stored in a Registry.

The registry stores well-known data defined by tracing: span relationships, metadata and reference counts. Additional user-defined data provided by Layers, such as formatted fields, metrics, or distributed traces should be stored in the extensions typemap.